@@ -93,7 +93,7 @@ class ComplianceClient:
 
     def get_profiles(self, search):
         response = self.conn.session.get("https://{0}/compliance/profiles".format(self.config.base_url),
-                                         params={'search': search})
+                                         params={'search': search, 'relationships': 'false'})
         logger.debug("Content of the response: {0} - {1}".format(response,
                                                                  response.json()))
         if response.status_code == 200:
