@@ -66,7 +66,7 @@ class Specs(SpecSet):
     cinder_conf = RegistryPoint()
     cinder_volume_log = RegistryPoint(filterable=True)
     cloud_init_custom_network = RegistryPoint()
-    cloud_cfg = RegistryPoint()
+    cloud_cfg = RegistryPoint(filterable=True)
     cloud_init_log = RegistryPoint(filterable=True)
     cluster_conf = RegistryPoint(filterable=True)
     cmdline = RegistryPoint()
@@ -90,6 +90,7 @@ class Specs(SpecSet):
     cpuinfo = RegistryPoint()
     cpupower_frequency_info = RegistryPoint()
     cpuset_cpus = RegistryPoint()
+    crio_conf = RegistryPoint(multi_output=True)
     cron_daily_rhsmd = RegistryPoint(filterable=True)
     crypto_policies_config = RegistryPoint()
     crypto_policies_state_current = RegistryPoint()
@@ -139,6 +140,7 @@ class Specs(SpecSet):
     dotnet_version = RegistryPoint()
     doveconf = RegistryPoint(filterable=True)
     dracut_kdump_capture_service = RegistryPoint()
+    dse_ldif = RegistryPoint(multi_output=True, filterable=True)
     du_dirs = RegistryPoint(multi_output=True)
     dumpe2fs_h = RegistryPoint(multi_output=True)
     engine_config_all = RegistryPoint()
@@ -223,6 +225,7 @@ class Specs(SpecSet):
     hosts = RegistryPoint()
     hponcfg_g = RegistryPoint()
     httpd_access_log = RegistryPoint(filterable=True)
+    httpd_cert_info_in_nss = RegistryPoint(multi_output=True, filterable=True)
     httpd_conf = RegistryPoint(multi_output=True)
     httpd_conf_scl_httpd24 = RegistryPoint(multi_output=True)
     httpd_conf_scl_jbcs_httpd24 = RegistryPoint(multi_output=True)
@@ -233,7 +236,7 @@ class Specs(SpecSet):
     httpd_M = RegistryPoint(multi_output=True)
     httpd_on_nfs = RegistryPoint()
     httpd_ssl_access_log = RegistryPoint(filterable=True)
-    httpd_ssl_cert_enddate = RegistryPoint()
+    httpd_ssl_cert_enddate = RegistryPoint(multi_output=True)
     httpd_ssl_error_log = RegistryPoint(filterable=True)
     httpd_V = RegistryPoint(multi_output=True)
     virt_uuid_facts = RegistryPoint()
@@ -273,6 +276,7 @@ class Specs(SpecSet):
     jboss_standalone_server_log = RegistryPoint(multi_output=True, filterable=True)
     jboss_standalone_main_config = RegistryPoint(multi_output=True)
     jboss_version = RegistryPoint(multi_output=True)
+    journal_all = RegistryPoint(filterable=True)
     journal_since_boot = RegistryPoint(filterable=True)
     katello_service_status = RegistryPoint(filterable=True)
     kdump_conf = RegistryPoint()
@@ -290,6 +294,7 @@ class Specs(SpecSet):
     kubepods_cpu_quota = RegistryPoint(multi_output=True)
     lastupload = RegistryPoint(multi_output=True)
     ld_library_path_of_user = RegistryPoint()
+    ldif_config = RegistryPoint(multi_output=True)
     libssh_client_config = RegistryPoint(filterable=True)
     libssh_server_config = RegistryPoint(filterable=True)
     libvirtd_log = RegistryPoint(filterable=True)
@@ -298,6 +303,7 @@ class Specs(SpecSet):
     locale = RegistryPoint()
     localtime = RegistryPoint()
     logrotate_conf = RegistryPoint(multi_output=True)
+    losetup = RegistryPoint()
     lpfc_max_luns = RegistryPoint()
     lpstat_p = RegistryPoint()
     lpstat_protocol_printers = RegistryPoint()
@@ -376,6 +382,7 @@ class Specs(SpecSet):
     mounts = RegistryPoint()
     mssql_conf = RegistryPoint()
     mssql_api_assessment = RegistryPoint()
+    mssql_tls_cert_enddate = RegistryPoint()
     multicast_querier = RegistryPoint()
     multipath_conf = RegistryPoint()
     multipath_conf_initramfs = RegistryPoint()
@@ -410,6 +417,7 @@ class Specs(SpecSet):
     nfs_exports_d = RegistryPoint(multi_output=True)
     nfs_exports = RegistryPoint()
     nginx_conf = RegistryPoint(multi_output=True)
+    nginx_ssl_cert_enddate = RegistryPoint(multi_output=True)
     nmcli_conn_show = RegistryPoint()
     nmcli_dev_show = RegistryPoint()
     nmcli_dev_show_sos = RegistryPoint(multi_output=True)
@@ -421,6 +429,7 @@ class Specs(SpecSet):
     nova_uid = RegistryPoint()
     nova_migration_uid = RegistryPoint()
     nscd_conf = RegistryPoint(filterable=True)
+    nss_rhel7 = RegistryPoint()
     nsswitch_conf = RegistryPoint(filterable=True)
     ntp_conf = RegistryPoint()
     ntpq_leap = RegistryPoint()
@@ -580,13 +589,16 @@ class Specs(SpecSet):
     sat5_insights_properties = RegistryPoint()
     satellite_compute_resources = RegistryPoint()
     satellite_content_hosts_count = RegistryPoint()
+    satellite_core_taskreservedresource_count = RegistryPoint()
     satellite_custom_ca_chain = RegistryPoint()
+    satellite_custom_hiera = RegistryPoint()
+    satellite_katello_empty_url_repositories = RegistryPoint()
     satellite_mongodb_storage_engine = RegistryPoint()
     satellite_non_yum_type_repos = RegistryPoint()
     satellite_sca_status = RegistryPoint()
     satellite_settings = RegistryPoint()
     satellite_version_rb = RegistryPoint()
-    satellite_custom_hiera = RegistryPoint()
+    satellite_yaml = RegistryPoint()
     scheduler = RegistryPoint(multi_output=True)
     sched_rt_runtime_us = RegistryPoint()
     scsi = RegistryPoint()
@@ -662,8 +674,10 @@ class Specs(SpecSet):
     systemctl_qpidd = RegistryPoint()
     systemctl_qdrouterd = RegistryPoint()
     systemctl_show_all_services = RegistryPoint()
+    systemctl_show_all_services_with_limited_properties = RegistryPoint()
     systemctl_show_target = RegistryPoint()
     systemctl_smartpdc = RegistryPoint()
+    systemctl_status_all = RegistryPoint(filterable=True)
     systemd_analyze_blame = RegistryPoint()
     systemd_docker = RegistryPoint()
     systemd_logind_conf = RegistryPoint()
