@@ -31,7 +31,11 @@ class InsightsArchiveSpecs(Specs):
     ceph_osd_tree = first_file(["insights_commands/ceph_osd_tree_-f_json-pretty", "insights_commands/ceph_osd_tree_-f_json"])
     ceph_s = first_file(["insights_commands/ceph_-s_-f_json-pretty", "insights_commands/ceph_-s_-f_json"])
     ceph_v = simple_file("insights_commands/ceph_-v")
-    certificates_enddate = first_file(["insights_commands/find_.etc.origin.node_.etc.origin.master_.etc.pki_.etc.ipa_-type_f_-exec_.usr.bin.openssl_x509_-noout_-enddate_-in_-exec_echo_FileName", "insights_commands/find_.etc.origin.node_.etc.origin.master_.etc.pki_-type_f_-exec_.usr.bin.openssl_x509_-noout_-enddate_-in_-exec_echo_FileName"])
+    certificates_enddate = first_file([
+        "insights_commands/find_.etc.origin.node_.etc.origin.master_.etc.pki_.etc.ipa_.etc.tower.tower.cert_-type_f_-exec_.usr.bin.openssl_x509_-noout_-enddate_-in_-exec_echo_FileName",
+        "insights_commands/find_.etc.origin.node_.etc.origin.master_.etc.pki_.etc.ipa_-type_f_-exec_.usr.bin.openssl_x509_-noout_-enddate_-in_-exec_echo_FileName",
+        "insights_commands/find_.etc.origin.node_.etc.origin.master_.etc.pki_-type_f_-exec_.usr.bin.openssl_x509_-noout_-enddate_-in_-exec_echo_FileName"
+    ])
     chkconfig = simple_file("insights_commands/chkconfig_--list")
     chronyc_sources = simple_file("insights_commands/chronyc_sources")
     corosync_cmapctl = glob_file("insights_commands/corosync-cmapctl*")
@@ -71,11 +75,12 @@ class InsightsArchiveSpecs(Specs):
     fw_devices = simple_file("insights_commands/fwupdagent_get-devices")
     fw_security = simple_file("insights_commands/fwupdagent_security_--force")
     gcp_license_codes = simple_file("insights_commands/python_-m_insights.tools.cat_--no-header_gcp_license_codes")
+    getcert_list = simple_file("insights_commands/getcert_list")
     getconf_page_size = simple_file("insights_commands/getconf_PAGE_SIZE")
     getenforce = simple_file("insights_commands/getenforce")
     getsebool = simple_file("insights_commands/getsebool_-a")
-    grub1_config_perms = simple_file("insights_commands/ls_-l_.boot.grub.grub.conf")
-    grub_config_perms = simple_file("insights_commands/ls_-l_.boot.grub2.grub.cfg")
+    grub1_config_perms = first_file(["insights_commands/ls_-lH_.boot.grub.grub.conf", "insights_commands/ls_-l_.boot.grub.grub.conf"])
+    grub_config_perms = first_file(["insights_commands/ls_-lH_.boot.grub2.grub.cfg", "insights_commands/ls_-l_.boot.grub2.grub.cfg"])
     grubby_default_index = simple_file("insights_commands/grubby_--default-index")
     grubby_default_kernel = simple_file("insights_commands/grubby_--default-kernel")
     gluster_v_info = simple_file("insights_commands/gluster_volume_info")
@@ -103,6 +108,7 @@ class InsightsArchiveSpecs(Specs):
     keystone_crontab = simple_file("insights_commands/crontab_-l_-u_keystone")
     kpatch_list = simple_file("insights_commands/kpatch_list")
     localtime = simple_file("insights_commands/file_-L_.etc.localtime")
+    losetup = simple_file("insights_commands/losetup_-l")
     lpstat_p = simple_file("insights_commands/lpstat_-p")
     ls_boot = simple_file("insights_commands/ls_-lanR_.boot")
     ls_dev = simple_file("insights_commands/ls_-lanR_.dev")
@@ -228,7 +234,7 @@ class InsightsArchiveSpecs(Specs):
     software_collections_list = simple_file('insights_commands/scl_--list')
     spamassassin_channels = simple_file('insights_commands/grep_-r_s_CHANNELURL_.etc.mail.spamassassin.channel.d')
     ss = simple_file("insights_commands/ss_-tupna")
-    sshd_config_perms = simple_file("insights_commands/ls_-l_.etc.ssh.sshd_config")
+    sshd_config_perms = first_file(["insights_commands/ls_-lH_.etc.ssh.sshd_config", "insights_commands/ls_-l_.etc.ssh.sshd_config"])
     subscription_manager_id = simple_file("insights_commands/subscription-manager_identity")
     subscription_manager_installed_product_ids = simple_file("insights_commands/find_.etc.pki.product-default._.etc.pki.product._-name_pem_-exec_rct_cat-cert_--no-content")
     sysctl = simple_file("insights_commands/sysctl_-a")
@@ -243,6 +249,7 @@ class InsightsArchiveSpecs(Specs):
     systemctl_qpidd = simple_file("insights_commands/systemctl_show_qpidd")
     systemctl_qdrouterd = simple_file("insights_commands/systemctl_show_qdrouterd")
     systemctl_show_all_services = simple_file("insights_commands/systemctl_show_.service")
+    systemctl_show_all_services_with_limited_properties = simple_file("insights_commands/systemctl_show_.service_--all_--property_Names_CPUAccounting_CPUQuotaPerSecUSec_CPUShares_StartupCPUShares_UnitFileState_SubState")
     systemctl_show_target = simple_file("insights_commands/systemctl_show_.target")
     systemctl_smartpdc = simple_file("insights_commands/systemctl_show_smart_proxy_dynflow_core")
     systemd_analyze_blame = simple_file("insights_commands/systemd-analyze_blame")
