@@ -1,4 +1,4 @@
-from insights.core.plugins import make_pass, make_fail
+from insights.core.plugins import make_pass, make_fail, make_none
 from insights.specs import Specs
 from insights.plugins import rules_fixture_plugin
 from insights.tests import InputData
@@ -36,5 +36,6 @@ def test_rules_fixture(run_rule):
     assert results == expected
 
     input_data = InputData('test_ret_none')
-    results = run_rule(rules_fixture_plugin.report, input_data)
-    assert results is None
+    results = run_rule(rules_fixture_plugin.report, input_data, return_make_none=True)
+    expected = make_none()
+    assert results == expected
